"use strict";

var zxcvbn = require('zxcvbn');

var DEFAULT_MIN_SCORE = 3;
/**
 * @typedef JoiInstance
 * @external "Joi"
 * @see {@link https://github.com/hapijs/joi/blob/v15.0.0/API.md#joi}
 */

/**
 * @typedef JoiExtension
 * @external "Extension"
 * @see {@link https://github.com/hapijs/joi/blob/v15.0.0/API.md#extension}
 */

/**
 * @param {JoiInstance} joi
 * @returns {JoiExtension}
 */

var joiZxcvbn = function joiZxcvbn(joi) {
  return {
    base: joi.string(),
    name: 'string',
    language: {
      zxcvbn: 'Password strength score {{!score}} does not suffice the minimum of {{!min}}'
    },
    rules: [{
      name: 'zxcvbn',
      params: {
        _minScore: joi.number().integer().min(0).max(4),
        _userInput: joi.array()
      },
      validate: function validate(params, value, state, options) {
        var min = typeof params._minScore === 'number' ? params._minScore : DEFAULT_MIN_SCORE;
        var result = zxcvbn(value || '', params._userInput);
        var score = result.score,
            feedback = result.feedback,
            calcTime = result.calc_time;

        if (score >= min) {
          return value;
        }

        return this.createError('string.zxcvbn', {
          score: score,
          calcTime: calcTime,
          feedback: feedback,
          min: min
        }, state, options);
      }
    }]
  };
};

module.exports = joiZxcvbn;
//# sourceMappingURL=index.js.map